@@ -6,6 +6,7 @@
 use serde::{Deserialize, Serialize};
 
 pub mod batcher;
+pub mod coupled;
 pub mod exclusive_gateway;
 pub mod gate;
 pub mod generator;
@@ -22,6 +23,7 @@ pub mod model_repr;
 pub mod model_trait;
 
 pub use self::batcher::Batcher;
+pub use self::coupled::{Coupled, ExternalInputCoupling, ExternalOutputCoupling, InternalCoupling};
 pub use self::exclusive_gateway::ExclusiveGateway;
 pub use self::gate::Gate;
 pub use self::generator::Generator;
